@@ -5,16 +5,17 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-logs", "1.53.0", __name__[0:-6], "aws-logs@1.53.0.jsii.tgz"
+    "@aws-cdk/aws-logs", "1.64.0", __name__[0:-6], "aws-logs@1.64.0.jsii.tgz"
 )
 
 __all__ = [
